import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.core._jsii
import aws_solutions_constructs.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-apigateway-lambda", "1.47.0", __name__[0:-6], "aws-apigateway-lambda@1.47.0.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
